pub struct BlockingPoolOpts {
pub max_threads: Option<usize>,
pub thread_keep_alive: Option<Duration>,
}Expand description
Configuration options for the blocking thread pool used by the runtime.
These options control the behavior of the blocking thread pool that handles
tokio::task::spawn_blocking tasks.
Fields
max_threads: Option<usize>The maximum number of threads in the blocking thread pool.
When not set, the tokio default (512) is used.
thread_keep_alive: Option<Duration>The duration that idle blocking threads are kept alive before being shut down.
When not set, the tokio default (10 seconds) is used.